##  FACT_SHEET_ARCHIVED

```
{
  "id": 42914,
  "type": "FactSheetArchivedEvent",
  "fsType": "Application",
  "userId": "3et65c21-98f2-5376-acaa-fchf654b9c22",
  "comment": "Duplicate application",
  "createdAt": "2024-02-16T13:49:42.181834Z",
  "fsIdAndRev": {
    "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
    "rev": 11
  },
  "workspaceId": "ae6756f1-4aag-4356-92c6-a390a60cb8fg",
  "affectedFactSheetIdAndRev": [
    {
      "id": "95fbeddd-abdf-4552-a82b-ce37c287735c",
      "rev": 11
    },
    {
      "id": "2efa37b5-18aa-48d8-9d70-1328c0d856d7",
      "rev": 27
    }
  ],
  "transactionSequenceNumber": 75126
}
```



